@@ -43,7 +43,7 @@ public:
     /**
      * Default Constructor
      */
-    AdviceSkroogoid(QObject* parent, const QVariantList& args);
+    explicit AdviceSkroogoid(QObject* parent, const QVariantList& args);
 
     /**
      * Reimplemented from Plasma::Applet
@@ -88,7 +88,7 @@ private:
 
     /**
      * A QHash to store Layouts for grouping
-     * advices per priority type
+     * advice per priority type
      */
     QHash<QString, Plasma::Frame*> priorityGroups;
 
