@@ -65,11 +65,11 @@ void BankSkroogoid::dataUpdated(const QString& sourceName, const Plasma::DataEng
 {
     if (sourceName != "Accounts") return;
     SKGTRACEIN(1, "BankSkroogoid::dataUpdated");
-    QHash<QString, QStringList> listData;
+    QHash<QString, QVariantHash> listData;
     for (int i = 0 ; i < engineData.keys().count() ; ++i) {
         const QString accountName = engineData.keys().at(i);
         QVariant accountValuesVariant = engineData.value(accountName);
-        QStringList accountValues = accountValuesVariant.value<QStringList>();
+        QVariantHash accountValues = accountValuesVariant.toHash();
 
         listData[accountName] = accountValues;
     }
@@ -104,16 +104,16 @@ void BankSkroogoid::dataUpdated(const QString& sourceName, const Plasma::DataEng
         // Account name
         QString account = listData.keys().at(i);
 
-        QStringList values = listData[account];
+        QVariantHash values = listData[account];
 
         // Bank
-        QString bank = values.at(0);
+        QString bank = values["bank"].toString();
 
         // Amount of money
-        double v1 = SKGServices::stringToDouble(values.at(2));
+        double v1 = values["amount"].toDouble();
 
         // Account closed
-        bool closed = (values.at(3) == "Y");
+        bool closed = (values["closed"] == "Y");
 
 
         // Display different sections depending on account types
@@ -191,24 +191,9 @@ void BankSkroogoid::dataUpdated(const QString& sourceName, const Plasma::DataEng
 
 void BankSkroogoid::openAccountTab(QString accountName)
 {
-    // Create a dom document, containing relevant parameters
-    QDomDocument params("SKGML");
-
-    // Get default parameters from the current Skrooge document
-    params.setContent(doc->getParameter("SKGOPERATION_DEFAULT_PARAMETERS"));
-    QDomElement root = params.documentElement();
-    if (root.isNull()) {
-        root = params.createElement("parameters");
-        params.appendChild(root);
-    }
-
-    // Add an attribute account with the account name
-    root.setAttribute("account", accountName);
-
     // And finally, open a new tab for this account
-    SKGMainPanel::getMainPanel()->openPage(SKGMainPanel::getMainPanel()->getPluginByName("Skrooge operation plugin"), -1, params.toString());
+    SKGMainPanel::getMainPanel()->openPage("skg://skrooge_operation_plugin/?account=" % SKGServices::encodeForUrl(accountName));
 }
 
-
 #include "bankskroogoid.moc"
 
