@@ -27,27 +27,44 @@
 #include "skginterfaceplugin.h"
 #include "skgtransactionmng.h"
 
-#include <KMenu>
-
 #include <QDomDocument>
 #include <QLayoutItem>
 #include <QToolButton>
 #include <QPushButton>
+#include <kmenu.h>
 
 SKGAdviceBoardWidget::SKGAdviceBoardWidget(SKGDocument* iDocument)
-    : SKGWidget(iDocument), m_maxAdvice(7), m_refreshNeeded(true)
+    : SKGBoardWidget(iDocument, i18nc("Dashboard widget title", "Advices")), m_maxAdvice(7), m_refreshNeeded(true), m_refresh(NULL)
 {
     SKGTRACEIN(10, "SKGAdviceBoardWidget::SKGAdviceBoardWidget");
 
-    ui.setupUi(this);
-
     //Create menu
     setContextMenuPolicy(Qt::ActionsContextMenu);
 
+    QWidget* g = new QWidget(this);
+    m_layout = new QFormLayout(g);
+    m_layout->setContentsMargins(0, 0, 0, 0);
+    m_layout->setObjectName(QString::fromUtf8("layout"));
+    m_layout->setFieldGrowthPolicy(QFormLayout::ExpandingFieldsGrow);
+    m_layout->setHorizontalSpacing(1);
+    m_layout->setVerticalSpacing(1);
+    setMainWidget(g);
+
+    //menu
     KAction* menuResetAdvice = new KAction(KIcon("edit-undo"), i18nc("Noun, a user action", "Activate all advice"), this);
     connect(menuResetAdvice, SIGNAL(triggered(bool)), this, SLOT(activateAllAdvice()));
     addAction(menuResetAdvice);
 
+    QAction* sep = new QAction(this);
+    sep->setSeparator(true);
+    addAction(sep);
+
+    m_menuAuto = new KAction(i18nc("Noun, a type of refresh for advice", "Automatic refresh"), this);
+    m_menuAuto->setCheckable(true);
+    m_menuAuto->setChecked(true);
+    connect(m_menuAuto, SIGNAL(triggered(bool)), this, SLOT(dataModified()));
+    addAction(m_menuAuto);
+
     //Refresh
     connect((const QObject*) getDocument(), SIGNAL(transactionSuccessfullyEnded(int)), this, SLOT(dataModified()), Qt::QueuedConnection);
     connect(SKGMainPanel::getMainPanel(), SIGNAL(currentPageChanged()), this, SLOT(pageChanged()), Qt::QueuedConnection);
@@ -57,6 +74,8 @@ SKGAdviceBoardWidget::SKGAdviceBoardWidget(SKGDocument* iDocument)
 SKGAdviceBoardWidget::~SKGAdviceBoardWidget()
 {
     SKGTRACEIN(10, "SKGAdviceBoardWidget::~SKGAdviceBoardWidget");
+    m_menuAuto = NULL;
+    m_refresh = NULL;
 }
 
 QString SKGAdviceBoardWidget::getState()
@@ -65,6 +84,7 @@ QString SKGAdviceBoardWidget::getState()
     QDomElement root = doc.createElement("parameters");
     doc.appendChild(root);
     root.setAttribute("maxAdvice", SKGServices::intToString(m_maxAdvice));
+    root.setAttribute("automatic", (m_menuAuto->isChecked() ? "Y" : "N"));
     return doc.toString();
 }
 
@@ -78,6 +98,15 @@ void SKGAdviceBoardWidget::setState(const QString& iState)
     if (maxAdviceS.isEmpty()) maxAdviceS = '7';
     m_maxAdvice = SKGServices::stringToInt(maxAdviceS);
 
+    QString automatic = root.attribute("automatic");
+    if (automatic.isEmpty()) automatic = 'Y';
+
+    if (m_menuAuto) {
+        bool previous = m_menuAuto->blockSignals(true);
+        m_menuAuto->setChecked(automatic == "Y");
+        m_menuAuto->blockSignals(previous);
+    }
+
     dataModified(true);
 }
 
@@ -86,12 +115,18 @@ void SKGAdviceBoardWidget::pageChanged()
     if (m_refreshNeeded) dataModified();
 }
 
+void SKGAdviceBoardWidget::dataModifiedForce()
+{
+    dataModified(true);
+}
+
 void SKGAdviceBoardWidget::dataModified(bool iForce)
 {
     SKGTRACEIN(10, "SKGAdviceBoardWidget::dataModified");
     SKGTabPage* page = SKGTabPage::parentTabPage(this);
-    if (!iForce && page != NULL && page != SKGMainPanel::getMainPanel()->currentPage()) {
+    if (!iForce && ((page != NULL && page != SKGMainPanel::getMainPanel()->currentPage()) || !m_menuAuto->isChecked())) {
         m_refreshNeeded = true;
+        if (m_refresh) m_refresh->show();
         return;
     }
     QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
@@ -99,14 +134,25 @@ void SKGAdviceBoardWidget::dataModified(bool iForce)
 
     //Remove all item of the layout
     QLayoutItem* child = NULL;
-    while ((child = ui.layout->takeAt(0)) != 0) {
+    while ((child = m_layout->takeAt(0)) != 0) {
         QWidget* w = child->widget();
         delete w;
         delete child;
     }
 
     //Get list of advice
+    double elapse = SKGServices::getMicroTime();
     SKGAdviceList globalAdviceList = SKGMainPanel::getMainPanel()->getAdvice();
+    elapse = SKGServices::getMicroTime() - elapse;
+
+    if (elapse > 3000 && m_menuAuto->isChecked()) {
+        SKGAdvice ad;
+        ad.setUUID("skgadviceboardwidget_verylong");
+        ad.setPriority(2);
+        ad.setShortMessage(i18nc("Advice on making the best (short)", "Advice are very long to compute"));
+        ad.setLongMessage(i18nc("Advice on making the best (long)", "To improve performances, you should switch the widget in 'Manual refresh' (see contextual menu)."));
+        globalAdviceList.push_back(ad);
+    }
 
     //Fill layout
     int nbDisplayedAdvice = 0;
@@ -142,10 +188,19 @@ void SKGAdviceBoardWidget::dataModified(bool iForce)
         KMenu* menu = new KMenu(this);
         menu->setIcon(icon->icon());
         for (int k = 0; k < nbSolution; ++k) {
-            QAction* act = menu->addAction(KIcon(k < nbSolution - 4 ?  "system-run" : "edit-delete"), autoCorrections.at(k), this, SLOT(adviceClicked()));
-            if (act) {
-                act->setProperty("id", ad.getUUID());
-                act->setProperty("solution", k < nbSolution - 4 ? k : k - nbSolution);
+            QString actionText = autoCorrections.at(k);
+            QAction* action = SKGMainPanel::getMainPanel()->getGlobalAction(QString(actionText).remove("skg://"), false);
+            if (action) {
+                //This is an action
+                QAction* act = menu->addAction(action->icon(), action->text(), SKGMainPanel::getMainPanel(), SLOT(openPage()));
+                act->setData(actionText);
+            } else {
+                //This is a text
+                QAction* act = menu->addAction(KIcon(k < nbSolution - 4 ?  "system-run" : "edit-delete"), autoCorrections.at(k), this, SLOT(adviceClicked()));
+                if (act) {
+                    act->setProperty("id", ad.getUUID());
+                    act->setProperty("solution", k < nbSolution - 4 ? k : k - nbSolution);
+                }
             }
         }
 
@@ -160,7 +215,7 @@ void SKGAdviceBoardWidget::dataModified(bool iForce)
         label->setToolTip(toolTip);
 
         //Add them
-        ui.layout->addRow(icon, label);
+        m_layout->addRow(icon, label);
 
         ++nbDisplayedAdvice;
     }
@@ -174,7 +229,7 @@ void SKGAdviceBoardWidget::dataModified(bool iForce)
         more->setCursor(Qt::PointingHandCursor);
         connect(more, SIGNAL(clicked(bool)), this, SLOT(moreAdvice()), Qt::QueuedConnection);
 
-        ui.layout->addRow(more, new QLabel(this));
+        m_layout->addRow(more, new QLabel(this));
     } else if (nbDisplayedAdvice > 7) {
         //Add less
         QPushButton*  less = new QPushButton(this);
@@ -184,25 +239,33 @@ void SKGAdviceBoardWidget::dataModified(bool iForce)
         less->setCursor(Qt::PointingHandCursor);
         connect(less, SIGNAL(clicked(bool)), this, SLOT(lessAdvice()), Qt::QueuedConnection);
 
-        ui.layout->addRow(less, new QLabel(this));
+        m_layout->addRow(less, new QLabel(this));
     }
 
+    //Add manual refresh button
+    m_refresh = new QPushButton(this);
+    m_refresh->setIcon(KIcon("view-refresh"));
+    m_refresh->setIconSize(QSize(22, 22));
+    m_refresh->setMaximumSize(QSize(22, 22));
+    m_refresh->setCursor(Qt::PointingHandCursor);
+    m_refresh->hide();
+    connect(m_refresh, SIGNAL(clicked(bool)), this, SLOT(dataModifiedForce()), Qt::QueuedConnection);
+
+    m_layout->addRow(m_refresh, new QLabel(this));
 
-    //Add spacer
-    ui.layout->addItem(new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding));
     QApplication::restoreOverrideCursor();
 }
 
 void SKGAdviceBoardWidget::moreAdvice()
 {
     m_maxAdvice = 9999999;
-    dataModified();
+    dataModifiedForce();
 }
 
 void SKGAdviceBoardWidget::lessAdvice()
 {
     m_maxAdvice = 7;
-    dataModified();
+    dataModifiedForce();
 }
 
 void SKGAdviceBoardWidget::activateAllAdvice()
@@ -223,55 +286,58 @@ void SKGAdviceBoardWidget::activateAllAdvice()
 void SKGAdviceBoardWidget::adviceClicked()
 {
     //Get advice identifier
-    QString uuid = sender()->property("id").toString();
-    if (!uuid.isEmpty()) {
-        //Get solution clicker
-        int solution = sender()->property("solution").toInt();
+    QAction* act = qobject_cast< QAction* >(sender());
+    if (act) {
+        QString uuid = act->property("id").toString();
+        if (!uuid.isEmpty()) {
+            //Get solution clicker
+            int solution = sender()->property("solution").toInt();
 
-        if (solution < 0) {
-            //We have to ignore this advice
-            SKGError err;
-            {
-                SKGBEGINLIGHTTRANSACTION(*getDocument(), i18nc("Noun, name of the user action", "Dismiss advice"), err);
-                QString currentMonth = QDate::currentDate().toString("yyyy-MM");
+            if (solution < 0) {
+                //We have to ignore this advice
+                SKGError err;
+                {
+                    SKGBEGINLIGHTTRANSACTION(*getDocument(), i18nc("Noun, name of the user action", "Dismiss advice"), err);
+                    QString currentMonth = QDate::currentDate().toString("yyyy-MM");
 
-                //Create dismiss
-                if (solution == -1 || solution == -2) uuid = SKGServices::splitCSVLine(uuid, '|').at(0);
-                err = getDocument()->setParameter(uuid, solution == -2 || solution == -4 ? "I" : QString("I_" % currentMonth), QVariant(), "advice");
+                    //Create dismiss
+                    if (solution == -1 || solution == -2) uuid = SKGServices::splitCSVLine(uuid, '|').at(0);
+                    err = getDocument()->setParameter(uuid, solution == -2 || solution == -4 ? "I" : QString("I_" % currentMonth), QVariant(), "advice");
 
-                //Delete useless dismiss
-                if (!err)err = getDocument()->executeSqliteOrder("DELETE FROM parameters WHERE t_uuid_parent='advice' AND t_value like 'I_ % ' AND t_value!='I_" % currentMonth % '\'');
+                    //Delete useless dismiss
+                    if (!err)err = getDocument()->executeSqliteOrder("DELETE FROM parameters WHERE t_uuid_parent='advice' AND t_value like 'I_ % ' AND t_value!='I_" % currentMonth % '\'');
+                }
+
+                //status bar
+                if (!err) err = SKGError(0, i18nc("Successful message after an user action", "Advice dismissed."));
+                else err.addError(ERR_FAIL, i18nc("Error message",  "Advice dismiss failed"));
+            } else {
+                //Get last transaction id
+                int previous = getDocument()->getTransactionToProcess();
+
+                //Execute the advice correction on all plugin
+                QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
+                int index = 0;
+                while (index >= 0) {
+                    SKGInterfacePlugin* plugin = SKGMainPanel::getMainPanel()->getPluginByIndex(index);
+                    if (plugin) {
+                        SKGError err = plugin->executeAdviceCorrection(uuid, solution);
+                        if (!err || err.getReturnCode() != ERR_NOTIMPL) {
+                            //The correction has been done or failed. This is the end.
+                            index = -2;
+                        }
+                    } else index = -2;
+                    ++index;
+                }
+
+                //Get last transaction id
+                int next = getDocument()->getTransactionToProcess();
+
+                //If this is the same transaction, it means that an action has been done outside the document ==> a refresh is needed
+                if (next == previous) emit refreshNeeded();
+
+                QApplication::restoreOverrideCursor();
             }
-
-            //status bar
-            if (!err) err = SKGError(0, i18nc("Successful message after an user action", "Advice dismissed."));
-            else err.addError(ERR_FAIL, i18nc("Error message",  "Advice dismiss failed"));
-        } else {
-            //Get last transaction id
-            int previous = getDocument()->getTransactionToProcess();
-
-            //Execute the advice correction on all plugin
-            QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
-            int index = 0;
-            while (index >= 0) {
-                SKGInterfacePlugin* plugin = SKGMainPanel::getMainPanel()->getPluginByIndex(index);
-                if (plugin) {
-                    SKGError err = plugin->executeAdviceCorrection(uuid, solution);
-                    if (!err || err.getReturnCode() != ERR_NOTIMPL) {
-                        //The correction has been done or failed. This is the end.
-                        index = -2;
-                    }
-                } else index = -2;
-                ++index;
-            }
-
-            //Get last transaction id
-            int next = getDocument()->getTransactionToProcess();
-
-            //If this is the same transaction, it means that an action has been done outside the document ==> a refresh is needed
-            if (next == previous) emit refreshNeeded();
-
-            QApplication::restoreOverrideCursor();
         }
     }
 }
