@@ -21,14 +21,16 @@
 *
 * @author Stephane MANKOWSKI / Guillaume DE BURE
 */
-#include "ui_skgadviceboardwidget.h"
-#include "skgwidget.h"
+#include "skgboardwidget.h"
 
+class QFormLayout;
+class KAction;
+class QPushButton;
 
 /**
  * This file is plugin for advice
  */
-class SKGAdviceBoardWidget : public SKGWidget
+class SKGAdviceBoardWidget : public SKGBoardWidget
 {
     Q_OBJECT
 
@@ -63,6 +65,7 @@ Q_SIGNALS:
 
 private Q_SLOTS:
     void pageChanged();
+    void dataModifiedForce();
     void dataModified(bool iForce = false);
     void adviceClicked();
     void activateAllAdvice();
@@ -70,11 +73,14 @@ private Q_SLOTS:
     void lessAdvice();
 
 private:
-    Q_DISABLE_COPY(SKGAdviceBoardWidget);
-    Ui::skgadviceboardwidget ui;
+    Q_DISABLE_COPY(SKGAdviceBoardWidget)
 
     int m_maxAdvice;
     bool m_refreshNeeded;
+
+    KAction* m_menuAuto;
+    QPushButton* m_refresh;
+    QFormLayout* m_layout;
 };
 
 #endif // SKGADVICEBOARDWIDGET_H
