@@ -22,12 +22,12 @@
 * @author Stephane MANKOWSKI / Guillaume DE BURE
 */
 #include "ui_skgtipofdayboardwidget.h"
-#include "skgwidget.h"
+#include "skgboardwidget.h"
 
 /**
  * This file is a plugin for tip of day
  */
-class SKGTipOfDayBoardWidget : public SKGWidget
+class SKGTipOfDayBoardWidget : public SKGBoardWidget
 {
     Q_OBJECT
 
@@ -46,7 +46,7 @@ private Q_SLOTS:
     void onModified();
 
 private:
-    Q_DISABLE_COPY(SKGTipOfDayBoardWidget);
+    Q_DISABLE_COPY(SKGTipOfDayBoardWidget)
 
     Ui::skgtipofdayboardwidget ui;
 };
