@@ -31,8 +31,6 @@
 #include <kstandardaction.h>
 #include <krecentfilesaction.h>
 #include <kfiledialog.h>
-#include <kmessagebox.h>
-#include <kinputdialog.h>
 #include <ksplashscreen.h>
 #include <kcmdlineargs.h>
 #include <kaboutdata.h>
@@ -43,6 +41,7 @@
 
 #include <QtGui/QWidget>
 #include <QFile>
+#include <kmessagewidget.h>
 
 /**
  * This plugin factory.
@@ -338,6 +337,16 @@ void SKGFilePlugin::onSaveAs()
     }
 }
 
+void SKGFilePlugin::onReOpen()
+{
+    QAction* act = qobject_cast< QAction* >(sender());
+    if (act) {
+        QString filename = act->data().toString();
+        QFile(SKGDocument::getTemporaryFile(filename)).remove();
+        onOpen(filename);
+    }
+}
+
 void SKGFilePlugin::onOpen(const KUrl& iUrl)
 {
     SKGError err;
@@ -355,12 +364,15 @@ void SKGFilePlugin::onOpen(const KUrl& iUrl)
             bool restoreTmpFile = false;
             QString tmpFile = SKGDocument::getTemporaryFile(fileName);
             if (QFile(tmpFile).exists()) {
-                int conf = KMessageBox::questionYesNo(SKGMainPanel::getMainPanel(),
-                                                      i18nc("Question", "The temporary file of your document already exists. Do you want to restore it?"),
-                                                      i18nc("Question", "Restore temporary file"),
-                                                      KStandardGuiItem::yes(),
-                                                      KStandardGuiItem::no());
-                if (conf == KMessageBox::Yes) restoreTmpFile = true;
+                KMessageWidget* msg = SKGMainPanel::getMainPanel()->displayMessage(i18nc("Warning message", "Your document has been restored from its temporary file. You can decide to reopen the original document."), SKGDocument::Warning);
+                QAction* reopen = new QAction(i18nc("Noun", "Reopen"), msg);
+                reopen->setIcon(KIcon("skg_open"));
+                reopen->setData(fileName);
+                msg->addAction(reopen);
+                connect(reopen, SIGNAL(triggered(bool)), this, SLOT(onReOpen()));
+                connect(reopen, SIGNAL(triggered(bool)), msg, SLOT(deleteLater()), Qt::QueuedConnection);
+
+                restoreTmpFile = true;
             }
 
             //Open
