@@ -53,7 +53,7 @@ SKGImportPluginJson::~SKGImportPluginJson()
 bool SKGImportPluginJson::isExportPossible()
 {
     SKGTRACEIN(10, "SKGImportPluginCsv::isExportPossible");
-    return (!m_importer ? true : QFileInfo(m_importer->getFileName()).suffix().toUpper() == "JSON");
+    return (!m_importer ? true : m_importer->getFileNameExtension() == "JSON");
 }
 
 SKGError SKGImportPluginJson::exportFile()
@@ -62,10 +62,10 @@ SKGError SKGImportPluginJson::exportFile()
     QString doc;
     err = SKGServices::copySqliteDatabaseToJson(m_importer->getDocument()->getDatabase(), doc);
     if (!err) {
-        KSaveFile file(m_importer->getLocalFileName());
+        KSaveFile file(m_importer->getLocalFileName(false));
         if (!file.open()) {
             err.setReturnCode(ERR_INVALIDARG);
-            err.setMessage(i18nc("Error message",  "Save file '%1' failed", m_importer->getFileName()));
+            err.setMessage(i18nc("Error message",  "Save file '%1' failed", m_importer->getFileName().prettyUrl()));
         } else {
             QTextStream stream(&file);
             if (!m_importer->getCodec().isEmpty()) stream.setCodec(m_importer->getCodec().toAscii().constData());
