@@ -323,7 +323,7 @@ SKGError SKGImportPluginMmb::importFile()
                             //Case transfert
                             if (!err && idTarget != "-1") {
                                 SKGOperationObject op2;
-                                err = op.duplicate(op2);
+                                err = op.duplicate(op2, op.getDate());
                                 if (!err) err = op2.setStatus(op.getStatus());
                                 if (!err) err = op2.bookmark(op.isBookmarked());
                                 if (!err) err = op2.setAttribute("t_imported", "T");
