@@ -29,7 +29,7 @@
 class SKGImportPluginMT940 : public SKGImportPlugin
 {
     Q_OBJECT
-    Q_INTERFACES(SKGImportPlugin);
+    Q_INTERFACES(SKGImportPlugin)
 
 public:
     /**
@@ -64,7 +64,7 @@ public:
 
 
 private:
-    Q_DISABLE_COPY(SKGImportPluginMT940);
+    Q_DISABLE_COPY(SKGImportPluginMT940)
 };
 
 #endif // SKGIMPORTPLUGINMT940_H
