@@ -96,16 +96,28 @@ SKGBoardWidget* SKGBankPlugin::getDashboardWidget(int iIndex)
     if (iIndex == 0) return new SKGAccountBoardWidget(m_currentBankDocument);
     else if (iIndex == 1) return new SKGHtmlBoardWidget(m_currentBankDocument,
                                      getDashboardWidgetTitle(iIndex),
-                                     KStandardDirs().findResource("data", KGlobal::mainComponent().aboutData()->appName() % "/html/default/account_table.html"),
-                                     QStringList() << "v_account_display", true);
-    else if (iIndex == 2) return new SKGHtmlBoardWidget(m_currentBankDocument,
-                                     getDashboardWidgetTitle(iIndex),
-                                     KStandardDirs().findResource("data", KGlobal::mainComponent().aboutData()->appName() % "/html/default/bank_table_light.html"),
-                                     QStringList() << "v_account_display");
-    else if (iIndex == 3) return new SKGHtmlBoardWidget(m_currentBankDocument,
-                                     getDashboardWidgetTitle(iIndex),
-                                     KStandardDirs().findResource("data", KGlobal::mainComponent().aboutData()->appName() % "/html/default/bank_table.html"),
+                                     KStandardDirs().findResource("data", "skrooge/html/default/account_table.html"),
                                      QStringList() << "v_account_display", true);
+    else if (iIndex == 2) {
+        SKGHtmlBoardWidget* w = new SKGHtmlBoardWidget(m_currentBankDocument,
+                getDashboardWidgetTitle(iIndex),
+                KStandardDirs().findResource("data", "skrooge/html/default/bank_table_light.html"),
+                QStringList() << "v_account_display");
+
+        QStringList overlayopen;
+        overlayopen.push_back("skg_open");
+        KAction* open = new KAction(KIcon("view-investment", NULL, overlayopen), i18nc("Verb", "Open report..."), w);
+        connect(open, SIGNAL(triggered(bool)), SKGMainPanel::getMainPanel(), SLOT(openPage()));
+        QString url = QString("skg://skrooge_report_plugin/?grouped=Y&transfers=Y&tracked=Y&expenses=Y&incomes=Y&lines2=t_BANK&currentPage=-1&mode=0&interval=3&period=0") %
+                      "&tableAndGraphState.graphMode=2&tableAndGraphState.allPositive=N&tableAndGraphState.show=graph&columns=" % SKGServices::encodeForUrl("#NOTHING#");
+        open->setData(url);
+
+        w->addAction(open);
+        return w;
+    } else if (iIndex == 3) return new SKGHtmlBoardWidget(m_currentBankDocument,
+                                       getDashboardWidgetTitle(iIndex),
+                                       KStandardDirs().findResource("data", "skrooge/html/default/bank_table.html"),
+                                       QStringList() << "v_account_display", true);
     return NULL;
 }
 
@@ -206,7 +218,7 @@ SKGAdviceList SKGBankPlugin::advice(const QStringList& iIgnoredAdvice)
     //Get accounts closed with money
     if (!iIgnoredAdvice.contains("skgbankplugin_closedaccount")) {
         SKGStringListList result;
-        m_currentBankDocument->executeSelectSqliteOrder("SELECT t_name FROM v_account WHERE f_CURRENTAMOUNT>0.1 AND t_close='Y'", result);
+        m_currentBankDocument->executeSelectSqliteOrder("SELECT t_name FROM v_account_amount WHERE f_CURRENTAMOUNT>0.1 AND t_close='Y'", result);
         int nb = result.count();
         for (int i = 1; i < nb; ++i) { //Ignore header
             //Get parameters
