@@ -134,7 +134,7 @@ Q_SIGNALS:
 private Q_SLOTS:
     void import(const QString& iFile);
     void import(const QList<KUrl>& iFiles = QList<KUrl>());
-    void importbackends();
+    SKGError importbackends();
     void exportFile();
     void findTransfers();
     void anonymize();
@@ -142,6 +142,7 @@ private Q_SLOTS:
     void validateImportedOperations();
     void validateAllOperations();
     void mergeImportedOperation();
+    void onInstall();
 private:
     Q_DISABLE_COPY(SKGImportExportPlugin)
     void openLastModifiedIfSetting();
@@ -159,7 +160,10 @@ private:
 
     SKGDocumentBank* m_currentBankDocument;
 
+    QString m_docUniqueIdentifier;
+
     Ui::skgimportexportplugin_pref ui;
+    bool m_install;
 };
 
 #endif // SKGDEBUGPLUGIN_H
