@@ -55,6 +55,9 @@ SKGReportPluginWidget::SKGReportPluginWidget(SKGDocumentBank* iDocument, bool iM
     ui.kCorrectedBy->setCurrentIndex(0);
     ui.kCorrectedBy->setWhereClauseCondition("t_type='I'");
 
+    ui.kCorrectedByMode->addItem("x");
+    ui.kCorrectedByMode->addItem("/");
+
     ui.kLineLabel->setText("");
     ui.kPeriod->setCurrentIndex(1);
     ui.kInterval->setCurrentIndex(2);
@@ -115,14 +118,15 @@ SKGReportPluginWidget::SKGReportPluginWidget(SKGDocumentBank* iDocument, bool iM
     //Init comboboxes
     m_attsForColumns << "d_date" << "d_DATEWEEK" << "d_DATEMONTH" << "d_DATEQUARTER" << "d_DATESEMESTER" << "d_DATEYEAR";
     m_attsForLines << "#NOTHING#" <<
-                   "t_BANK" << "t_ACCOUNTTYPE" << "t_ACCOUNT" <<
+                   "t_BANK" << "t_ACCOUNTTYPE" << "t_ACCOUNT" << "t_TOACCOUNT" <<
                    "t_REALCATEGORY" <<
                    "t_PAYEE" <<
                    "t_TYPEEXPENSENLS" <<
                    "t_mode" <<
                    "t_status" <<
                    "t_UNITTYPE" << "t_UNIT" <<
-                   "t_REALREFUND";
+                   "t_REALREFUND" <<
+                   "t_TRANSFER" ;
 
     //Adding properties
     QStringList properties;
@@ -163,6 +167,7 @@ SKGReportPluginWidget::SKGReportPluginWidget(SKGDocumentBank* iDocument, bool iM
     connect(ui.kForecastCmb, SIGNAL(currentIndexChanged(int)) , this, SLOT(refresh()), Qt::QueuedConnection);
     connect(ui.kForecastValue, SIGNAL(valueChanged(int)) , this, SLOT(refresh()), Qt::QueuedConnection);
     connect(ui.kCorrectedBy, SIGNAL(currentIndexChanged(int)) , this, SLOT(refresh()), Qt::QueuedConnection);
+    connect(ui.kCorrectedByMode, SIGNAL(currentIndexChanged(int)) , this, SLOT(refresh()), Qt::QueuedConnection);
 
     connect((const QObject*) getDocument(), SIGNAL(tableModified(QString,int)), this, SLOT(dataModified(QString,int)));
     connect(SKGMainPanel::getMainPanel(), SIGNAL(currentPageChanged()), this, SLOT(pageChanged()), Qt::QueuedConnection);
@@ -241,6 +246,7 @@ QString SKGReportPluginWidget::getState()
     root.setAttribute("forecastValue", SKGServices::intToString(ui.kForecastValue->value()));
     root.setAttribute("zoomPosition", SKGServices::intToString(zoomPosition()));
     root.setAttribute("correctedby", ui.kCorrectedBy->currentText());
+    root.setAttribute("correctedbymode", ui.kCorrectedByMode->currentText());
 
     if (!m_operationWhereClause.isEmpty()) root.setAttribute("operationWhereClause", m_operationWhereClause);
 
@@ -282,6 +288,7 @@ void SKGReportPluginWidget::setState(const QString& iState)
     QString nbLevelColumnsString = root.attribute("nbLevelColumns");
     QString zoomPosition = root.attribute("zoomPosition");
     QString correctedby = root.attribute("correctedby");
+    QString correctedbymode = root.attribute("correctedbymode");
 
     //Default values
     if (nbLevelLinesString.isEmpty()) nbLevelLinesString = '0';
@@ -327,6 +334,7 @@ void SKGReportPluginWidget::setState(const QString& iState)
     ui.kForecastValue->setValue(SKGServices::stringToInt(forecastValue));
     if (!zoomPosition.isEmpty()) setZoomPosition(SKGServices::stringToInt(zoomPosition));
     if (!correctedby.isEmpty()) ui.kCorrectedBy->setCurrentIndex(ui.kCorrectedBy->findText(correctedby));
+    if (!correctedbymode.isEmpty()) ui.kCorrectedByMode->setCurrentIndex(ui.kCorrectedByMode->findText(correctedbymode));
 
     refresh();
 
@@ -788,6 +796,7 @@ void SKGReportPluginWidget::refresh()
 
     int mode = ui.kMode->itemData(ui.kMode->currentIndex()).toInt();
     ui.kCorrectedBy->setEnabled(mode != 3);
+    ui.kCorrectedByMode->setEnabled(mode != 3);
 
     //Check dates
     ui.kDateSelect->setVisible(p > 0);
@@ -917,7 +926,7 @@ void SKGReportPluginWidget::dataModified(const QString& iTableName, int iIdTrans
                         if (nb) {
                             //Get most active account
                             SKGStringListList list;
-                            err = doc->executeSelectSqliteOrder("SELECT account.id FROM account, operation WHERE operation.rd_account_id=account.id AND d_date>date('now', '-3 month') GROUP BY (t_name) ORDER BY COUNT(1) DESC LIMIT 1", list);
+                            err = doc->executeSelectSqliteOrder("SELECT account.id FROM account, operation WHERE +operation.rd_account_id=account.id AND d_date>date('now', '-3 month') GROUP BY (t_name) ORDER BY COUNT(1) DESC LIMIT 1", list);
                             if (!err && list.count() == 2) {
                                 SKGAccountObject account(doc, SKGServices::stringToInt(list.at(1).at(0)));
                                 err = account.load();
@@ -1008,7 +1017,9 @@ void SKGReportPluginWidget::dataModified(const QString& iTableName, int iIdTrans
                 if (ui.kCorrectedBy->currentIndex() > 0 && mode != 3) {
                     SKGUnitObject unit = ui.kCorrectedBy->getUnit();
                     QString id = SKGServices::intToString(unit.getID());
-                    coef = "*COALESCE((SELECT u1.f_quantity FROM unitvalue u1 where u1.rd_unit_id=" % id % " and u1.d_date=(SELECT MAX(u2.d_date) FROM unitvalue u2 where u2.rd_unit_id=" % id % " and u2.d_date<=v_operation_consolidated.d_date)), (SELECT u1.f_quantity FROM unitvalue u1 where u1.rd_unit_id=" % id % " and u1.d_date=(SELECT MIN(u2.d_date) FROM unitvalue u2 where u2.rd_unit_id=" % id % ")),0)";
+                    if (ui.kCorrectedByMode->currentIndex() == 0) coef = '*';
+                    else coef = '/';
+                    coef = coef % "COALESCE((SELECT u1.f_quantity FROM unitvalue u1 where u1.rd_unit_id=" % id % " and u1.d_date=(SELECT MAX(u2.d_date) FROM unitvalue u2 where u2.rd_unit_id=" % id % " and u2.d_date<=v_operation_consolidated.d_date)), (SELECT u1.f_quantity FROM unitvalue u1 where u1.rd_unit_id=" % id % " and u1.d_date=(SELECT MIN(u2.d_date) FROM unitvalue u2 where u2.rd_unit_id=" % id % ")),0)";
                 }
 
                 if (!err) err = doc->getConsolidatedView(tableName, attCol, attLine, "f_REALCURRENTAMOUNT" % coef,
