@@ -660,7 +660,7 @@ bool SKGObjectModel::setData(const QModelIndex& index, const QVariant& value, in
                 SKGAccountObject obj(getObject(index));
                 SKGBEGINLIGHTTRANSACTION(*getDocument(),
                                          ((Qt::CheckState) value.toInt() == Qt::Checked ? i18nc("Noun, name of the user action", "Close account '%1'", obj.getName()) : i18nc("Noun, name of the user action", "Open account '%1'", obj.getName())), err);
-                if (abs(obj.getCurrentAmount()) > 0.01) err = getDocument()->sendMessage(i18nc("An information message",  "Warning, you closed an account with money"));
+                if (abs(obj.getCurrentAmount()) > 0.01) err = getDocument()->sendMessage(i18nc("An information message",  "Warning, you closed an account with money"), SKGDocument::Warning);
                 if (!err) err = obj.setClosed((Qt::CheckState) value.toInt() == Qt::Checked);
                 if (!err) err = obj.save();
             } else if (m_trackerTable) {
