@@ -199,30 +199,41 @@ double SKGAccountObject::getCurrentAmount() const
 
 double SKGAccountObject::getAmount(const QDate& iDate) const
 {
+    SKGTRACEIN(10, "SKGAccountObject::getAmount");
     double output = 0;
     if (getDocument()) {
-        SKGStringListList listTmp;
-        SKGError err = getDocument()->executeSelectSqliteOrder("SELECT TOTAL(f_QUANTITY), rc_unit_id FROM v_operation  WHERE "
-                       "d_date<='" % SKGServices::dateToSqlString(QDateTime(iDate)) % "' AND t_template='N' AND rd_account_id=" % SKGServices::intToString(getID()) %
-                       " GROUP BY rc_unit_id",
-                       listTmp);
-        int nb = listTmp.count();
-        for (int i = 1; !err && i < nb ; ++i) {
-            QString quantity = listTmp.at(i).at(0);
-            QString unitid = listTmp.at(i).at(1);
+        //Search result in cache
+        QString ids = SKGServices::intToString(getID());
+        QString dates = SKGServices::dateToSqlString(QDateTime(iDate));
+        QString key = "getamount-" % ids % '-' % dates;
+        QString val = getDocument()->getCachedValue(key);
+        if (val.isEmpty()) {
+            SKGStringListList listTmp;
+            SKGError err = getDocument()->executeSelectSqliteOrder("SELECT TOTAL(f_QUANTITY), rc_unit_id FROM v_operation_tmp1  WHERE "
+                           "d_date<='" % dates % "' AND t_template='N' AND rd_account_id=" % ids %
+                           " GROUP BY rc_unit_id",
+                           listTmp);
+            int nb = listTmp.count();
+            for (int i = 1; !err && i < nb ; ++i) {
+                QString quantity = listTmp.at(i).at(0);
+                QString unitid = listTmp.at(i).at(1);
 
-            double coef = 1;
-            QString val = getDocument()->getCachedValue("unitvalue-" % unitid);
-            if (!val.isEmpty()) {
-                //Yes
-                coef = SKGServices::stringToDouble(val);
-            } else {
-                //No
-                SKGUnitObject unit(getDocument(), SKGServices::stringToInt(unitid));
-                if (unit.getType() != SKGUnitObject::PRIMARY) coef = unit.getAmount(iDate);
+                double coef = 1;
+                QString val = getDocument()->getCachedValue("unitvalue-" % unitid);
+                if (!val.isEmpty()) {
+                    //Yes
+                    coef = SKGServices::stringToDouble(val);
+                } else {
+                    //No
+                    SKGUnitObject unit(getDocument(), SKGServices::stringToInt(unitid));
+                    if (unit.getType() != SKGUnitObject::PRIMARY) coef = unit.getAmount(iDate);
+                }
+
+                output += coef * SKGServices::stringToDouble(quantity);
             }
-
-            output += coef * SKGServices::stringToDouble(quantity);
+            ((SKGDocument*) getDocument())->addValueInCache(key, SKGServices::doubleToString(output));
+        } else {
+            output = SKGServices::stringToDouble(val);
         }
     }
     return output;
