@@ -240,7 +240,7 @@ public:
      * Finalize an import by changing state and applying rules
      *   @see SKGError
      */
-    virtual SKGError finalizedImportedOperations();
+    virtual SKGError finalizeImportation();
 private:
     Q_DISABLE_COPY(SKGImportExportManager)
 
