@@ -184,12 +184,12 @@ QString SKGOperationObject::getComment() const
     return getAttribute("t_comment");
 }
 
-SKGError SKGOperationObject::setNumber(int iNumber)
+SKGError SKGOperationObject::setNumber(qlonglong iNumber)
 {
     return setAttribute("i_number", SKGServices::intToString(iNumber));
 }
 
-int SKGOperationObject::getNumber() const
+qlonglong SKGOperationObject::getNumber() const
 {
     return SKGServices::stringToInt(getAttribute("i_number"));
 }
