@@ -75,7 +75,7 @@ SKGError SKGPayeeObject::createPayee(SKGDocumentBank* iDocument,
             if (!err) err = oPayee.save();
 
             if (!err && iSendPopupMessageOnCreation && iDocument) {
-                err = iDocument->sendMessage(i18nc("Information message", "Payee '%1' has been created" , iName), true);
+                err = iDocument->sendMessage(i18nc("Information message", "Payee '%1' has been created" , iName), SKGDocument::Positive);
             }
         }
     }
