@@ -75,7 +75,7 @@ SKGError SKGTrackerObject::createTracker(SKGDocumentBank* iDocument,
             if (!err) err = oTracker.save();
 
             if (!err && iSendPopupMessageOnCreation && iDocument) {
-                err = iDocument->sendMessage(i18nc("Information message", "Tracker '%1' has been created" , iName), true);
+                err = iDocument->sendMessage(i18nc("Information message", "Tracker '%1' has been created" , iName), SKGDocument::Positive);
             }
         }
     }
