@@ -28,7 +28,6 @@
 
 #include <klocale.h>
 #include <kglobal.h>
-#include <kio/netaccess.h>
 #include <kcurrencycode.h>
 #include <kstandarddirs.h>
 #include <ksavefile.h>
@@ -329,12 +328,12 @@ SKGError SKGUnitObject::createCurrencyUnit(SKGDocumentBank* iDocument, const QSt
     return err;
 }
 
-double SKGUnitObject::convert(double iValue, const SKGUnitObject& iUnitFrom, const SKGUnitObject& iUnitTo)
+double SKGUnitObject::convert(double iValue, const SKGUnitObject& iUnitFrom, const SKGUnitObject& iUnitTo, const QDate& iDate)
 {
     double output = iValue;
     if (iUnitFrom != iUnitTo) {
-        double valFrom = SKGServices::stringToDouble(iUnitFrom.getAttribute("f_CURRENTAMOUNT"));
-        double valTo = SKGServices::stringToDouble(iUnitTo.getAttribute("f_CURRENTAMOUNT"));
+        double valFrom = iUnitFrom.getAmount(iDate);
+        double valTo = iUnitTo.getAmount(iDate);
         output = iValue * valFrom / valTo;
     }
     return output;
@@ -651,7 +650,7 @@ QStringList SKGUnitObject::downloadSources()
     return sources;
 }
 
-SKGError SKGUnitObject::addSource(const QString& iNewSource)
+SKGError SKGUnitObject::addSource(const QString& iNewSource, bool iOpenSource)
 {
     SKGError err;
 
@@ -695,7 +694,7 @@ SKGError SKGUnitObject::addSource(const QString& iNewSource)
     }
 
     //Open the created or already existing file
-    QDesktopServices::openUrl(KUrl(newfile));
+    if (iOpenSource) QDesktopServices::openUrl(KUrl(newfile));
     return err;
 }
 
@@ -1112,7 +1111,7 @@ SKGError SKGUnitObject::downloadUnitValue(UnitDownloadMode iMode, int nbMaxValue
                             if (nbLoaded == 0) err = doc->sendMessage(i18nc("Information message", "Price not found for '%1' with regular expression '%2' in line '%3'", getName(), SKGServices::stringToHtml(price), data), SKGDocument::Warning); //TODO does not work with html
                         }
                     } else {
-                        doc->sendMessage(i18nc("An information message", "Open url '%1' failed: %2", path, KIO::NetAccess::lastErrorString()), SKGDocument::Warning);
+                        doc->sendMessage(i18nc("An information message", "Open url '%1' failed", path), SKGDocument::Warning);
                     }
                 }
             }
