@@ -31,7 +31,7 @@ SKGFlowLayout::SKGFlowLayout(QWidget* parent, int margin, int hSpacing, int vSpa
 }
 
 SKGFlowLayout::SKGFlowLayout(int margin, int hSpacing, int vSpacing)
-    : m_hSpace(hSpacing), m_vSpace(vSpacing)
+    : QLayout(), m_hSpace(hSpacing), m_vSpace(vSpacing)
 {
     setContentsMargins(margin, margin, margin, margin);
 }
