@@ -113,7 +113,12 @@ void SKGHtmlBoardWidget::dataModified(const QString& iTableName, int iIdTransact
             //Compute parameters
             QDate month = QDate::currentDate();
             month = month.addDays(-month.day() + 1);
-            if (m_previousMonth && m_previousMonth->isChecked()) month = month.addMonths(-1);
+            if (m_previousMonth) {
+                if (m_previousMonth->isChecked()) month = month.addMonths(-1);
+            } else {
+                //No mode "month" ==> we force to the infinite
+                month = QDate(2999, 12, 31);
+            }
             QString monthS = month.toString("yyyy-MM");
 
             //Set title
