@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
+ *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE support@mankowski.fr  *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -23,7 +23,7 @@
 
 #include <klineedit.h>
 
-SKGLineEdit::SKGLineEdit(QWidget *parent)
+SKGLineEdit::SKGLineEdit(QWidget* parent)
     : KLineEdit(parent), m_substringCompletionMode(true)
 {
 }
@@ -44,7 +44,8 @@ void SKGLineEdit::setSubstringCompletionMode(bool iMode)
 
 void SKGLineEdit::makeCompletion(const QString& text)
 {
-    if(m_substringCompletionMode) setCompletedItems(completionObject()->substringCompletion(text));
+    if (m_substringCompletionMode && completionMode() == KGlobalSettings::CompletionPopup)
+        setCompletedItems(completionObject()->substringCompletion(text));
     else KLineEdit::makeCompletion(text);
 }
 
