@@ -35,7 +35,7 @@ public:
      * Contructor
      * @param parent parent widget
      */
-    SKGSortFilterProxyModel(QObject* parent = 0);
+    explicit SKGSortFilterProxyModel(QObject* parent = 0);
 
     /**
      * Destructor
