@@ -74,7 +74,7 @@ int SKGUniqueApplication::newInstance()
         //Creation splash screen
         KConfigGroup pref = SKGMainPanel::getMainConfigGroup();
         if (pref.readEntry("show_splash_screen", true)) {
-            QString splashPathRelativePath = KCmdLineArgs::appName() % "/images/splash.png";
+            QString splashPathRelativePath = KGlobal::mainComponent().aboutData()->appName() % "/images/splash.png";
             QString splashPath = KStandardDirs::locate("data", splashPathRelativePath.toLatin1());
             if (!splashPath.isEmpty()) {
                 QPixmap pix(splashPath);
