@@ -36,6 +36,7 @@
 #include "skgshowdesignerplugin.h"
 #include "skgfilteredtableviewdesignerplugin.h"
 #include "skgwidgetselectordesignerplugin.h"
+#include "skgprogressbardesignerplugin.h"
 
 #include <QtPlugin>
 
@@ -58,6 +59,7 @@ SKGWidgetCollectionDesignerPlugin::SKGWidgetCollectionDesignerPlugin(QObject* pa
     m_widgets.append(new SKGWebViewDesignerPlugin(this));
     m_widgets.append(new SKGWidgetSelectorDesignerPlugin(this));
     m_widgets.append(new SKGZoomSelectorDesignerPlugin(this));
+    m_widgets.append(new SKGProgressBarDesignerPlugin(this));
 }
 
 QList<QDesignerCustomWidgetInterface*> SKGWidgetCollectionDesignerPlugin::customWidgets() const
