@@ -29,7 +29,7 @@
 class SKGWidgetSelectorDesignerPlugin : public QObject, public QDesignerCustomWidgetInterface
 {
     Q_OBJECT
-    Q_INTERFACES(QDesignerCustomWidgetInterface);
+    Q_INTERFACES(QDesignerCustomWidgetInterface)
 
 public:
     /**
