@@ -101,19 +101,19 @@ QString SKGServices::getenv(const QString& iAttribute)
     return QString::fromUtf8(qgetenv(iAttribute.toUtf8().constData()));
 }
 
-QString SKGServices::intToString(int iNumber)
+QString SKGServices::intToString(qlonglong iNumber)
 {
     QString output;
     output.setNum(iNumber);
     return output;
 }
 
-int SKGServices::stringToInt(const QString& iNumber)
+qlonglong SKGServices::stringToInt(const QString& iNumber)
 {
     if (iNumber.isEmpty()) return 0;
 
     bool ok;
-    int output = iNumber.toInt(&ok);
+    qlonglong output = iNumber.toLongLong(&ok);
     if (!ok) {
         SKGTRACE << "WARNING: SKGServices::stringToInt(" << iNumber << ") failed" << endl;
     }
@@ -273,6 +273,10 @@ QStringList SKGServices::splitCSVLine(const QString& iString, const QChar& iSepa
                     items.push_back(item);
                     item = "";
                     isInBlock = false;
+                    //320112 vvvv
+                    //Reset the block character to autorize mix
+                    cote = ' ';
+                    //320112 ^^^^
 
                     ++pos; //To ignore next separator
                     if (pos < nb) realSeparator = iString.at(pos); //To get the real separator
@@ -287,6 +291,10 @@ QStringList SKGServices::splitCSVLine(const QString& iString, const QChar& iSepa
             items.push_back(item);
             item = "";
             isInBlock = false;
+            //320112 vvvv
+            //Reset the block character to autorize mix
+            cote = ' ';
+            //320112 ^^^^
         } else {
             item += c;
         }
@@ -329,7 +337,16 @@ QString SKGServices::getDateFormat(const QStringList& iDates)
             val = val.replace("'20", "-20");
             val = val.replace("' ", "-200");
             val = val.replace('\'', "-20");
-            val = val.replace("-9", "-199");
+            val = val.replace("-90", "-1990");
+            val = val.replace("-91", "-1991");
+            val = val.replace("-92", "-1992");
+            val = val.replace("-93", "-1993");
+            val = val.replace("-94", "-1994");
+            val = val.replace("-95", "-1995");
+            val = val.replace("-96", "-1996");
+            val = val.replace("-97", "-1997");
+            val = val.replace("-98", "-1998");
+            val = val.replace("-99", "-1999");
             if (rx.indexIn(val) == -1) {
                 f_YYYY_MM_DD = false;
                 f_MM_DD_YY = false;
@@ -454,13 +471,13 @@ QString SKGServices::dateToSqlString(const QString& iDate, const QString& iForma
         DD = input.mid(6, 2);
 
     }
-    if (iFormat == "DDMMYYYY") {
+    if (iFormat == "DDMMYYYY" || iFormat == "DDMMYY") {
         YYYY = input.mid(4, 4);
         MM = input.mid(2, 2);
         DD = input.mid(0, 2);
 
     }
-    if (iFormat == "MMDDYYYY") {
+    if (iFormat == "MMDDYYYY" || iFormat == "MMDDYY") {
         YYYY = input.mid(4, 4);
         MM = input.mid(0, 2);
         DD = input.mid(2, 2);
@@ -474,7 +491,16 @@ QString SKGServices::dateToSqlString(const QString& iDate, const QString& iForma
         val = val.replace("'20", "-20");
         val = val.replace("' ", "-200");
         val = val.replace('\'', "-20");
-        val = val.replace("-9", "-199");
+        val = val.replace("-90", "-1990");
+        val = val.replace("-91", "-1991");
+        val = val.replace("-92", "-1992");
+        val = val.replace("-93", "-1993");
+        val = val.replace("-94", "-1994");
+        val = val.replace("-95", "-1995");
+        val = val.replace("-96", "-1996");
+        val = val.replace("-97", "-1997");
+        val = val.replace("-98", "-1998");
+        val = val.replace("-99", "-1999");
         QRegExp rx("(.+)-(.+)-(.+)");
         if (rx.indexIn(val) != -1) {
             QString v1 = rx.cap(1);
@@ -506,7 +532,7 @@ QString SKGServices::dateToSqlString(const QString& iDate, const QString& iForma
 
     QString date = YYYY % '-' % MM % '-' % DD;
     date.replace(' ', '0');
-    return dateToSqlString(stringToTime(date));
+    return dateToSqlString(QDateTime::fromString(date, "yyyy-MM-dd"));
 }
 
 QStringList SKGServices::tableToDump(const SKGStringListList& iTable, SKGServices::DumpMode iMode)
@@ -649,7 +675,7 @@ SKGError SKGServices::cryptFile(const QString& iFileSource, const QString& iFile
     QCA::Initializer init;
     if (!iPassword.isEmpty() && !QCA::isSupported("aes128-ecb")) {
         //Set error message
-        err.setReturnCode(ERR_WRITEACCESS); //To avoid password request
+        err.setReturnCode(ERR_INSTALL); //To avoid password request
         err.setMessage(i18nc("An error message about encryption", "AES128 encryption is not supported. Please install qca-ossl."));
     } else {
         // Create a random key - you'd probably use one from another
